Crossref APIs
rcrossref interacts with the main Crossref metadata search API at
https://github.com/CrossRef/rest-api-doc/blob/master/rest_api.md, the old metadata
search API at http://search.labs.crossref.org/, their DOI Content Negotiation
service at http://www.crosscite.org/cn/, and the Text and Data Mining
project http://tdmsupport.crossref.org/.Deprecated and Defunct
Note that functions that use the OpenURL service are now deprecated, and will be defunct
soon.What am I actually searching?
When you use the cr_*() functions in this package, you are using the Crossref
search API described at https://github.com/CrossRef/rest-api-doc/blob/master/rest_api.md.
When you search with query terms, on Crossref servers they are not searching full text, or
even abstracts of articles, but only what is available in the data that is returned to you.
That is, they search article titles, authors, etc. For some discussion on this, see
https://github.com/CrossRef/rest-api-doc/issues/101.Text mining
We provide the ability to do text mining in this package. See functions
cr_ft_links and cr_ft_text. However, another package
fulltext is designed solely for text mining, so try it for serious text
mining.High and Low Level APIs
For the Crossref search API (the functions cr_funders, cr_journals,
cr_licenses, cr_members, cr_prefixes,
cr_types, cr_works), there is a high level API and a low level.
The high level is accessible through those functions just listed (e.g., cr_works),
whereas the low level is accessible via the same fxn name with an underscore (e.g.,
cr_works_). The high level API does data requests, and parses to data.frame's.
Since the high level API functions have been around a while, we didn't want to break
their behavior, so the low level API functions are separate, and only do the data
request, giving back json or a list, with no attempt to parse any further. The
low level API functions will be faster because there's much less parsing, and
therefore less prone to potential errors due to changes in the Crossref API that
could cause parsing errors. Note that cursor feature works with both high and low level.